@@ -5,7 +5,7 @@ use Role::Tiny;
 use Carp qw/croak/;
 use Test::More ();
 
-our $VERSION = '1.003002'; # VERSION
+our $VERSION = '1.003003'; # VERSION
 
 sub d {
     my ( $self, $selector ) = @_;
@@ -14,7 +14,7 @@ sub d {
 
 sub da {
     my ( $self, $selector ) = @_;
-    my $markup = length $selector
+    my $markup = length($selector//'')
         ? $self->tx->res->dom->at($selector)
         : $self->tx->res->dom;
 
